SessionPropertyEventData class final

Represents a session property event.

Session properties apply to all events in the current session.

Example

import 'package:dynatrace_flutter_plugin/dynatrace_flutter_plugin.dart';

final event = SessionPropertyEventData()
  ..addSessionProperty('session_properties.product_tier', 'premium')
  ..addSessionProperty('session_properties.loyalty_status', 'gold');
Dynatrace().sendSessionPropertyEvent(event);
Inheritance

Constructors

SessionPropertyEventData({Map<String, dynamic> sessionProperties = const {}})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionProperties Map<String, dynamic>
final

Methods

addSessionProperty(String key, dynamic value) → void
Adds a session property.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited