WebRequestTiming class abstract
The Web request timing interface which can be used to measure a web request manually
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getRequestTag(
) → String - Returns a unique x-dynatrace header for the web request, which has to be manually added as http header. The header key can be obtained with the method getRequestTagHeader. The string value can be empty in cases when the agent is not able to send data. E.g. the agent is turned off completly, has not started yet or is not allowed to track web requests because of privacy reasons. The tag value is evaluated by the corresponding web server agent. The Dynatrace server will link the server-side PurePath data with this mobile user action. For more information, see Dynatrace documentation.
-
getRequestTagHeader(
) → String - Returns the name for the header that is needed in order to track a request For more information, see Dynatrace documentation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startWebRequestTiming(
) → void - Start the measurement of the web request. Call this before the request is started.
-
stopWebRequestTiming(
int responseCode, String? responseMessage) → void -
Stops the measurement of the web request. This needs to be called after the request is executed.
The
responseCodeandresponseMessagewill be transferred and shown in the web UI. -
stopWebRequestTimingWithSize(
int responseCode, String? responseMessage, int requestSize, int responseSize) → void -
Stops the measurement of the web request. This needs to be called after the request is executed.
The
responseCode,responseMessage,responseSizeandrequestSizewill be transferred and shown in the web UI. /// Example: -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited